import { useState } from "react";
import { currentUser, login, User } from "./api";
import Header from "./Header";

export interface LoginProps {
  onLogin: (user: User) => void;
}

export const Login = ({ onLogin }: LoginProps) => {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [error, setError] = useState<unknown>(null);
  const [loading, setLoading] = useState(false);

  async function doLogin() {
    setLoading(true);
    setError(null);
    const timeout = new Promise((r) => setTimeout(r, 1000));
    let user: User;
    try {
      await login({ username, password });
      user = await currentUser();
    } catch (e) {
      await timeout;
      setError(e);
      setLoading(false);
      return;
    }
    await timeout;
    onLogin(user);
  }

  function handleSubmit(e: React.FormEvent) {
    e.preventDefault();
    doLogin();
  }

  return (
    <>
      <Header />
      <form onSubmit={handleSubmit}>
        <div>
          <input
            type="text"
            id="username"
            name="username"
            placeholder="username"
            required
            value={username}
            onChange={(evt) => setUsername(evt.target.value)}
          />
        </div>
        <div>
          <input
            type="password"
            id="password"
            name="password"
            placeholder="password"
            minLength={8}
            value={password}
            required
            onChange={(evt) => setPassword(evt.target.value)}
          />
        </div>
        <button type="submit" value="login" style={{ fontSize: "small" }}>
          login
        </button>
        {loading && <span className="loader" />}
      </form>
    </>
  );
};
